from django.db import models


class ComponentSession(models.Model):
    """A model for storing component parameters.
    All queries must be routed through `django_idom.config.IDOM_DATABASE`.
    """

    uuid = models.UUIDField(primary_key=True, editable=False, unique=True)  # type: ignore
    params = models.BinaryField(editable=False)  # type: ignore
    last_accessed = models.DateTimeField(auto_now_add=True)  # type: ignore



from logging import getLogger

from django_idom import components, decorators, hooks, types, utils
from django_idom.websocket.paths import IDOM_WEBSOCKET_PATH


logger = getLogger(__name__)

print("WARNING: django-idom has been renamed to reactpy-django.")
logger.warning("django-idom has been renamed to reactpy-django.")

__version__ = "3.0.1"
__all__ = [
    "IDOM_WEBSOCKET_PATH",
    "hooks",
    "components",
    "decorators",
    "types",
    "utils",
]



from __future__ import annotations

from django.conf import settings
from django.core.cache import DEFAULT_CACHE_ALIAS
from django.db import DEFAULT_DB_ALIAS
from idom.config import IDOM_DEBUG_MODE
from idom.core.types import ComponentConstructor

from django_idom.types import Postprocessor, ViewComponentIframe
from django_idom.utils import import_dotted_path


# Not user configurable settings
IDOM_DEBUG_MODE.set_current(getattr(settings, "DEBUG"))
IDOM_REGISTERED_COMPONENTS: dict[str, ComponentConstructor] = {}
IDOM_VIEW_COMPONENT_IFRAMES: dict[str, ViewComponentIframe] = {}


# Configurable through Django settings.py
IDOM_WEBSOCKET_URL = getattr(
    settings,
    "IDOM_WEBSOCKET_URL",
    "idom/",
)
IDOM_RECONNECT_MAX = getattr(
    settings,
    "IDOM_RECONNECT_MAX",
    259200,  # Default to 3 days
)
IDOM_CACHE: str = getattr(
    settings,
    "IDOM_CACHE",
    DEFAULT_CACHE_ALIAS,
)
IDOM_DATABASE: str = getattr(
    settings,
    "IDOM_DATABASE",
    DEFAULT_DB_ALIAS,
)
IDOM_DEFAULT_QUERY_POSTPROCESSOR: Postprocessor | None = import_dotted_path(
    getattr(
        settings,
        "IDOM_DEFAULT_QUERY_POSTPROCESSOR",
        "django_idom.utils.django_query_postprocessor",
    )
)



# Generated by Django 4.1.6 on 2023-02-21 10:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_idom", "0002_rename_created_at_componentparams_last_accessed"),
    ]

    operations = [
        migrations.CreateModel(
            name="ComponentSession",
            fields=[
                (
                    "uuid",
                    models.UUIDField(
                        editable=False, primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("params", models.BinaryField()),
                ("last_accessed", models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.DeleteModel(
            name="ComponentParams",
        ),
    ]
